import pytest
from datadoc_model.model import (
    DatadocMetadata,
    MetadataContainer,
    PseudonymizationMetadata,
)
from pydantic import ValidationError


def test_instantiate_no_values_container():
    container = MetadataContainer()
    assert isinstance(container, MetadataContainer)


def test_instantiate_no_values_datadoc():
    datadoc = DatadocMetadata()
    assert isinstance(datadoc, DatadocMetadata)


def test_instantiate_no_values_pseudo():
    pseudo = PseudonymizationMetadata()
    assert isinstance(pseudo, PseudonymizationMetadata)


def test_unknown_field():
    with pytest.raises(ValidationError):
        DatadocMetadata(unknown_field="random_value")



"""This module is a backwards compatibility shim, to support `from datadoc_model.model import xxx` formats"""

import warnings

warnings.warn(
    message="datadoc_model.model has been moved to datadoc_model.all_optional.model. Please update imports accordingly. This will be removed in the next major release.",
    category=DeprecationWarning,
    stacklevel=2,
)

from .all_optional.model import *  # noqa: E402, F403
